@@ -67,7 +67,7 @@ static void setup_weather_updates (ClockLocation *loc);
 static gchar *clock_location_get_valid_weather_code (const gchar *code);
 
 ClockLocation *
-clock_location_find_and_ref (GList       *locations,
+clock_location_find_and_ref (GSList       *locations,
                              const gchar *name,
                              const gchar *city,
                              const gchar *timezone,
@@ -75,11 +75,12 @@ clock_location_find_and_ref (GList       *locations,
                              gfloat       longitude,
                              const gchar *code)
 {
-        GList *l;
-        ClockLocationPrivate *priv;
+        GSList *l;
 
         for (l = locations; l != NULL; l = l->next) {
-                priv = clock_location_get_instance_private (l->data);
+
+                ClockLocationPrivate *priv =
+                        clock_location_get_instance_private (l->data);
 
                 if (priv->latitude == latitude &&
                     priv->longitude == longitude &&
@@ -91,7 +92,7 @@ clock_location_find_and_ref (GList       *locations,
         }
 
         if (l != NULL)
-                return g_object_ref (CLOCK_LOCATION (l->data));
+                return CLOCK_LOCATION (l->data);
         else
                 return NULL;
 }
@@ -209,35 +210,14 @@ clock_location_finalize (GObject *g_obj)
                                               G_CALLBACK (network_changed),
                                               CLOCK_LOCATION (g_obj));
 
-        if (priv->name) {
-                g_free (priv->name);
-                priv->name = NULL;
-        }
+        g_clear_pointer (&priv->name, g_free);
+        g_clear_pointer (&priv->city, g_free);
 
-        if (priv->city) {
-                g_free (priv->city);
-                priv->city = NULL;
-        }
+        g_clear_object (&priv->systz);
 
-        if (priv->systz) {
-                g_object_unref (priv->systz);
-                priv->systz = NULL;
-        }
-
-        if (priv->timezone) {
-                g_free (priv->timezone);
-                priv->timezone = NULL;
-        }
-
-        if (priv->tzname) {
-                g_free (priv->tzname);
-                priv->tzname = NULL;
-        }
-
-        if (priv->weather_code) {
-                g_free (priv->weather_code);
-                priv->weather_code = NULL;
-        }
+        g_clear_pointer (&priv->timezone, g_free);
+        g_clear_pointer (&priv->tzname, g_free);
+        g_clear_pointer (&priv->weather_code, g_free);
 
         if (priv->weather_info) {
                 weather_info_free (priv->weather_info);
@@ -276,11 +256,7 @@ clock_location_set_name (ClockLocation *loc, const gchar *name)
 {
         ClockLocationPrivate *priv = clock_location_get_instance_private (loc);
 
-        if (priv->name) {
-                g_free (priv->name);
-                priv->name = NULL;
-        }
-
+        g_free (priv->name);
         priv->name = g_strdup (name);
 }
 
@@ -297,11 +273,7 @@ clock_location_set_city (ClockLocation *loc, const gchar *city)
 {
         ClockLocationPrivate *priv = clock_location_get_instance_private (loc);
 
-        if (priv->city) {
-                g_free (priv->city);
-                priv->city = NULL;
-        }
-
+        g_free (priv->city);
         priv->city = g_strdup (city);
 }
 
@@ -318,11 +290,7 @@ clock_location_set_timezone (ClockLocation *loc, const gchar *timezone)
 {
         ClockLocationPrivate *priv = clock_location_get_instance_private (loc);
 
-        if (priv->timezone) {
-                g_free (priv->timezone);
-                priv->timezone = NULL;
-        }
-
+        g_free (priv->timezone);
         priv->timezone = g_strdup (timezone);
 }
 
@@ -359,16 +327,11 @@ clock_location_set_tzname (ClockLocation *this, const char *tzname)
 {
         ClockLocationPrivate *priv = clock_location_get_instance_private (CLOCK_LOCATION(this));
 
-        if (priv->tzname) {
-                if (strcmp (priv->tzname, tzname) == 0) {
-                        return;
-                }
+        if (priv->tzname && strcmp (priv->tzname, tzname) == 0)
+                return;
 
-                g_free (priv->tzname);
-                priv->tzname = NULL;
-        }
-
-        if (tzname) {
+        g_free (priv->tzname);
+        if (tzname && *tzname != '\0') {
                 priv->tzname = g_strdup (tzname);
         } else {
                 priv->tzname = NULL;
@@ -471,7 +434,6 @@ clock_location_is_current (ClockLocation *loc)
         return FALSE;
 }
 
-
 glong
 clock_location_get_offset (ClockLocation *loc)
 {
@@ -595,7 +557,7 @@ clock_location_make_current (ClockLocation *loc,
 static gchar *
 clock_location_get_valid_weather_code (const gchar *code)
 {
-        if (!code || code[0] == '\0')
+        if (!code || *code == '\0')
                 return g_strdup (WEATHER_EMPTY_CODE);
         else
                 return g_strdup (code);
@@ -683,8 +645,9 @@ update_weather_info (gpointer data)
                 DISTANCE_UNIT_KM
         };
 
-        // set temperature and speed units only if different from
-        // invalid/default
+        /* set temperature and speed units only if different from
+         * invalid/default
+         */
         if (priv->temperature_unit > TEMP_UNIT_DEFAULT)
                 prefs.temperature_unit = priv->temperature_unit;
         if (priv->speed_unit > SPEED_UNIT_DEFAULT)
