@@ -73,7 +73,6 @@ static void (*parent_class_style_updated) (GtkWidget *widget);
 static void (*parent_class_change_background)(MatePanelApplet* panel_applet, MatePanelAppletBackgroundType type, GdkRGBA* color, cairo_pattern_t* pattern);
 static void (*parent_class_change_orient)(MatePanelApplet       *panel_applet, MatePanelAppletOrient  orient);
 
-
 #ifdef PROVIDE_WATCHER_SERVICE
 /* Quite dirty way of providing the org.kde.StatusNotifierWatcher service
  * ourselves, in case the session doesn't already */
@@ -103,7 +102,6 @@ sn_watcher_service_ref (void)
 }
 #endif
 
-
 static GtkOrientation
 get_gtk_orientation_from_applet_orient (MatePanelAppletOrient orient)
 {
@@ -141,7 +139,7 @@ static void
 setup_gsettings (NaTrayApplet *applet)
 {
   applet->priv->settings = mate_panel_applet_settings_new (MATE_PANEL_APPLET (applet), NA_TRAY_SCHEMA);
-  g_signal_connect_object (G_OBJECT(applet->priv->settings), "changed::" KEY_MIN_ICON_SIZE, G_CALLBACK (gsettings_changed_min_icon_size), applet, 0);
+  g_signal_connect (applet->priv->settings, "changed::" KEY_MIN_ICON_SIZE, G_CALLBACK (gsettings_changed_min_icon_size), applet);
 }
 
 static void
@@ -201,7 +199,7 @@ ensure_prefs_window_is_created (NaTrayApplet *applet)
   g_signal_connect_swapped (applet->priv->dialog->preferences_dialog, "response",
                             G_CALLBACK (na_preferences_dialog_response), applet);
 
-  g_signal_connect (G_OBJECT (applet->priv->dialog->preferences_dialog), "delete_event",
+  g_signal_connect (applet->priv->dialog->preferences_dialog, "delete-event",
                     G_CALLBACK (na_preferences_dialog_hide_event), applet);
 }
 
@@ -300,7 +298,6 @@ static const GtkActionEntry menu_actions [] = {
 	  G_CALLBACK (about_cb) }
 };
 
-
 static void
 na_tray_applet_realize (GtkWidget *widget)
 {
