@@ -156,7 +156,7 @@ compare_size (gconstpointer a,
 }
 
 static cairo_surface_t *
-get_surface (SnIconPixmap  **icon_pixmap,
+get_surface (SnItemV0       *v0,
              GtkOrientation  orientation,
              gint            size)
 {
@@ -165,10 +165,10 @@ get_surface (SnIconPixmap  **icon_pixmap,
   SnIconPixmap *pixmap = NULL;
   GList *l;
 
-  g_assert (icon_pixmap != NULL && icon_pixmap[0] != NULL);
+  g_assert (v0->icon_pixmap != NULL && v0->icon_pixmap[0] != NULL);
 
-  for (i = 0; icon_pixmap[i] != NULL; i++)
-    pixmaps = g_list_prepend (pixmaps, icon_pixmap[i]);
+  for (i = 0; v0->icon_pixmap[i] != NULL; i++)
+    pixmaps = g_list_prepend (pixmaps, v0->icon_pixmap[i]);
 
   pixmaps = g_list_sort_with_data (pixmaps, compare_size,
                                    GUINT_TO_POINTER (orientation));
@@ -234,9 +234,6 @@ get_icon_by_name (const gchar *icon_name,
                                       NULL, GTK_ICON_LOOKUP_FORCE_SIZE, NULL);
 }
 
-#define ICON_NAME_VALID(icon_name) (icon_name && icon_name[0] != '\0')
-#define ICON_PIXMAP_VALID(icon_pixmap) (icon_pixmap && icon_pixmap[0] != NULL)
-
 static void
 update (SnItemV0 *v0)
 {
@@ -245,9 +242,6 @@ update (SnItemV0 *v0)
   SnTooltip *tip;
   gint icon_size;
   gboolean visible;
-  const gchar *icon_name;
-  SnIconPixmap **icon_pixmap;
-
   g_return_if_fail (SN_IS_ITEM_V0 (v0));
 
   image = GTK_IMAGE (v0->image);
@@ -257,43 +251,23 @@ update (SnItemV0 *v0)
   else
     icon_size = MAX (1, v0->effective_icon_size);
 
-  /* If the item requests attention and has a specific icon for it, use that
-   * instead of the default icon. */
-  if (g_strcmp0 (v0->status, "NeedsAttention") == 0 &&
-      (ICON_NAME_VALID (v0->attention_icon_name) ||
-       ICON_PIXMAP_VALID (v0->attention_icon_pixmap)))
-    {
-      icon_name = v0->attention_icon_name;
-      icon_pixmap = v0->attention_icon_pixmap;
-    }
-  else
-    {
-      icon_name = v0->icon_name;
-      icon_pixmap = v0->icon_pixmap;
-    }
-
-  if (ICON_NAME_VALID (icon_name))
+  if (v0->icon_name != NULL && v0->icon_name[0] != '\0')
     {
       cairo_surface_t *surface;
       gint scale;
 
       scale = gtk_widget_get_scale_factor (GTK_WIDGET (image));
-      surface = get_icon_by_name (icon_name, icon_size, scale);
+      surface = get_icon_by_name (v0->icon_name, icon_size, scale);
 
       if (!surface)
         {
           GdkPixbuf *pixbuf;
           /*try to find icons specified by path and filename*/
-          pixbuf = gdk_pixbuf_new_from_file (icon_name, NULL);
+          pixbuf = gdk_pixbuf_new_from_file (v0->icon_name, NULL);
           if (pixbuf && icon_size > 1)
             {
               /*An icon specified by path and filename may be the wrong size for the tray */
-              GdkPixbuf *scaled_pixbuf;
-
-              scaled_pixbuf = gdk_pixbuf_scale_simple (pixbuf, icon_size-2, icon_size-2, GDK_INTERP_BILINEAR);
-              g_object_unref (pixbuf);
-              pixbuf = scaled_pixbuf;
-
+              pixbuf = gdk_pixbuf_scale_simple (pixbuf, icon_size-2, icon_size-2, GDK_INTERP_BILINEAR);
               surface = gdk_cairo_surface_create_from_pixbuf (pixbuf, scale, NULL);
             }
           if (pixbuf)
@@ -307,11 +281,11 @@ update (SnItemV0 *v0)
       gtk_image_set_from_surface (image, surface);
       cairo_surface_destroy (surface);
     }
-  else if (ICON_PIXMAP_VALID (icon_pixmap))
+  else if (v0->icon_pixmap != NULL && v0->icon_pixmap[0] != NULL)
     {
       cairo_surface_t *surface;
 
-      surface = get_surface (icon_pixmap,
+      surface = get_surface (v0,
                              gtk_orientable_get_orientation (GTK_ORIENTABLE (v0)),
                              icon_size);
       if (surface != NULL)
@@ -666,7 +640,7 @@ update_title (GObject      *source_object,
 
   v0 = SN_ITEM_V0 (user_data);
 
-  g_clear_pointer (&v0->title, g_free);
+  g_free (v0->title);
   v0->title = g_variant_dup_string (variant, NULL);
   g_clear_pointer (&variant, g_variant_unref);
 
@@ -694,7 +668,7 @@ update_icon_name (GObject      *source_object,
 
   v0 = SN_ITEM_V0 (user_data);
 
-  g_clear_pointer (&v0->icon_name, g_free);
+  g_free (v0->icon_name);
   v0->icon_name = g_variant_dup_string (variant, NULL);
   g_clear_pointer (&variant, g_variant_unref);
 
@@ -745,7 +719,7 @@ update_overlay_icon_name (GObject      *source_object,
 
   v0 = SN_ITEM_V0 (user_data);
 
-  g_clear_pointer (&v0->overlay_icon_name, g_free);
+  g_free (v0->overlay_icon_name);
   v0->overlay_icon_name = g_variant_dup_string (variant, NULL);
   g_clear_pointer (&variant, g_variant_unref);
 
@@ -796,7 +770,7 @@ update_attention_icon_name (GObject      *source_object,
 
   v0 = SN_ITEM_V0 (user_data);
 
-  g_clear_pointer (&v0->attention_icon_name, g_free);
+  g_free (v0->attention_icon_name);
   v0->attention_icon_name = g_variant_dup_string (variant, NULL);
   g_clear_pointer (&variant, g_variant_unref);
 
@@ -818,7 +792,7 @@ update_attention_icon_pixmap (GObject      *source_object,
 
   v0 = SN_ITEM_V0 (user_data);
 
-  g_clear_pointer (&v0->attention_icon_pixmap, icon_pixmap_free);
+  icon_pixmap_free (v0->attention_icon_pixmap);
   v0->attention_icon_pixmap = icon_pixmap_new (variant);
   g_clear_pointer (&variant, g_variant_unref);
 
@@ -847,7 +821,7 @@ update_tooltip (GObject      *source_object,
 
   v0 = SN_ITEM_V0 (user_data);
 
-  g_clear_pointer (&v0->tooltip, sn_tooltip_free);
+  sn_tooltip_free (v0->tooltip);
   v0->tooltip = sn_tooltip_new (variant);
   g_clear_pointer (&variant, g_variant_unref);
 
