@@ -288,8 +288,6 @@ preview_window_thumbnail (WnckWindow   *wnck_window,
 		*thumbnail_width = (int) ((double) width * ratio);
 	}
 
-	gdk_x11_display_error_trap_push (gdk_window_get_display (window));
-
 	thumbnail = cairo_image_surface_create (CAIRO_FORMAT_ARGB32,
 	                                        *thumbnail_width,
 	                                        *thumbnail_height);
@@ -300,12 +298,6 @@ preview_window_thumbnail (WnckWindow   *wnck_window,
 	cairo_paint (cr);
 	cairo_destroy (cr);
 
-	if (gdk_x11_display_error_trap_pop (gdk_window_get_display (window)))
-	{
-		cairo_surface_destroy (thumbnail);
-		thumbnail = NULL;
-	}
-
 	g_object_unref (window);
 
 	return thumbnail;
@@ -413,7 +405,10 @@ static gboolean applet_enter_notify_event (WnckTasklist *tl, GList *wnck_windows
 
 	gtk_widget_show (tasklist->preview);
 
-	g_signal_connect_data (G_OBJECT (tasklist->preview), "draw", G_CALLBACK (preview_window_draw), thumbnail, (GClosureNotify) G_CALLBACK (cairo_surface_destroy), 0);
+	g_signal_connect_data (tasklist->preview, "draw",
+	                       G_CALLBACK (preview_window_draw), thumbnail,
+	                       (GClosureNotify) G_CALLBACK (cairo_surface_destroy),
+	                       0);
 
 	return FALSE;
 }
@@ -597,7 +592,6 @@ static void tasklist_update_unminimization_radio(TasklistData* tasklist)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
 }
 
-
 static void move_unminimized_windows_changed(GSettings* settings, gchar* key, TasklistData* tasklist)
 {
 	gboolean value;
@@ -803,8 +797,12 @@ gboolean window_list_applet_fill(MatePanelApplet* applet)
 		wnck_tasklist_set_icon_loader(WNCK_TASKLIST(tasklist->tasklist), icon_loader_func, tasklist, NULL);
 
 #ifdef HAVE_WINDOW_PREVIEWS
-		g_signal_connect(G_OBJECT(tasklist->tasklist), "task_enter_notify", G_CALLBACK(applet_enter_notify_event), tasklist);
-		g_signal_connect(G_OBJECT(tasklist->tasklist), "task_leave_notify", G_CALLBACK(applet_leave_notify_event), tasklist);
+		g_signal_connect (tasklist->tasklist, "task-enter-notify",
+		                  G_CALLBACK (applet_enter_notify_event),
+		                  tasklist);
+		g_signal_connect (tasklist->tasklist, "task-leave-notify",
+		                  G_CALLBACK (applet_leave_notify_event),
+		                  tasklist);
 #endif /* HAVE_WINDOW_PREVIEWS */
 	}
 	else
@@ -824,25 +822,36 @@ gboolean window_list_applet_fill(MatePanelApplet* applet)
 
 	tasklist_apply_orientation(tasklist);
 
-	g_signal_connect(G_OBJECT(tasklist->tasklist), "destroy", G_CALLBACK(destroy_tasklist), tasklist);
-	g_signal_connect(G_OBJECT(tasklist->applet), "size_allocate", G_CALLBACK(applet_size_allocate), tasklist);
+	g_signal_connect (tasklist->tasklist, "destroy",
+	                  G_CALLBACK (destroy_tasklist),
+	                  tasklist);
+	g_signal_connect (tasklist->applet, "size-allocate",
+	                  G_CALLBACK (applet_size_allocate),
+	                  tasklist);
 
 	gtk_container_add(GTK_CONTAINER(tasklist->applet), tasklist->tasklist);
 
-	g_signal_connect(G_OBJECT(tasklist->applet), "realize", G_CALLBACK(applet_realized), tasklist);
-	g_signal_connect(G_OBJECT(tasklist->applet), "change_orient", G_CALLBACK(applet_change_orient), tasklist);
-	g_signal_connect(G_OBJECT(tasklist->applet), "change_size", G_CALLBACK(applet_change_pixel_size), tasklist);
-	g_signal_connect(G_OBJECT(tasklist->applet), "change_background", G_CALLBACK(applet_change_background), tasklist);
+	g_signal_connect (tasklist->applet, "realize",
+	                  G_CALLBACK (applet_realized),
+	                  tasklist);
+	g_signal_connect (tasklist->applet, "change-orient",
+	                  G_CALLBACK (applet_change_orient),
+	                  tasklist);
+	g_signal_connect (tasklist->applet, "change-size",
+	                  G_CALLBACK (applet_change_pixel_size),
+	                  tasklist);
+	g_signal_connect (tasklist->applet, "change-background",
+	                  G_CALLBACK(applet_change_background),
+	                  tasklist);
 
 	action_group = gtk_action_group_new("Tasklist Applet Actions");
 	gtk_action_group_set_translation_domain(action_group, GETTEXT_PACKAGE);
 	gtk_action_group_add_actions(action_group, tasklist_menu_actions, G_N_ELEMENTS(tasklist_menu_actions), tasklist);
 
-
 	/* disable the item of system monitor, if not exists.
 	 * example, mate-system-monitor, o gnome-system-monitor */
 	char* programpath;
-	int i;
+	gsize i;
 
 	for (i = 0; i < G_N_ELEMENTS(system_monitors); i += 1)
 	{
@@ -864,7 +873,6 @@ gboolean window_list_applet_fill(MatePanelApplet* applet)
 	_system_monitor_found:;
 	/* end of system monitor item */
 
-
 	mate_panel_applet_setup_menu_from_resource (MATE_PANEL_APPLET (tasklist->applet),
 	                                            WNCKLET_RESOURCE_PATH "window-list-menu.xml",
 	                                            action_group);
@@ -888,7 +896,7 @@ gboolean window_list_applet_fill(MatePanelApplet* applet)
 
 static void call_system_monitor(GtkAction* action, TasklistData* tasklist)
 {
-	int i;
+	gsize i;
 
 	for (i = 0; i < G_N_ELEMENTS(system_monitors); i += 1)
 	{
@@ -906,7 +914,6 @@ static void call_system_monitor(GtkAction* action, TasklistData* tasklist)
 	}
 }
 
-
 static void display_help_dialog(GtkAction* action, TasklistData* tasklist)
 {
 	wncklet_display_help(tasklist->applet, "mate-user-guide", "windowlist", WINDOW_LIST_ICON);
@@ -1020,7 +1027,6 @@ static void setup_dialog(GtkBuilder* builder, TasklistData* tasklist)
 {
 	GtkWidget* button;
 
-
 	tasklist->wayland_info_label = WID("wayland_info_label");
 	tasklist->show_current_radio = WID("show_current_radio");
 	tasklist->show_all_radio = WID("show_all_radio");
@@ -1070,9 +1076,15 @@ static void setup_dialog(GtkBuilder* builder, TasklistData* tasklist)
 	g_object_set_data(G_OBJECT(tasklist->auto_group_radio), "group_value", "auto");
 	g_object_set_data(G_OBJECT(tasklist->always_group_radio), "group_value", "always");
 
-	g_signal_connect(G_OBJECT(tasklist->never_group_radio), "toggled", (GCallback) group_windows_toggled, tasklist);
-	g_signal_connect(G_OBJECT(tasklist->auto_group_radio), "toggled", (GCallback) group_windows_toggled, tasklist);
-	g_signal_connect(G_OBJECT(tasklist->always_group_radio), "toggled", (GCallback) group_windows_toggled, tasklist);
+	g_signal_connect (tasklist->never_group_radio, "toggled",
+	                  (GCallback) group_windows_toggled,
+	                  tasklist);
+	g_signal_connect (tasklist->auto_group_radio, "toggled",
+	                  (GCallback) group_windows_toggled,
+	                  tasklist);
+	g_signal_connect (tasklist->always_group_radio, "toggled",
+	                  (GCallback) group_windows_toggled,
+	                  tasklist);
 
 	/* Mouse Scroll: */
 	g_settings_bind (tasklist->settings,
@@ -1084,19 +1096,29 @@ static void setup_dialog(GtkBuilder* builder, TasklistData* tasklist)
 #ifdef HAVE_WINDOW_PREVIEWS
 	/* change thumbnail size: */
 	tasklist_update_thumbnail_size_spin(tasklist);
-	g_signal_connect(G_OBJECT(tasklist->thumbnail_size_spin), "value-changed", (GCallback) thumbnail_size_spin_changed, tasklist);
+	g_signal_connect (tasklist->thumbnail_size_spin, "value-changed",
+	                  (GCallback) thumbnail_size_spin_changed,
+	                  tasklist);
 #endif
 
 	/* move window when unminimizing: */
 	tasklist_update_unminimization_radio(tasklist);
-	g_signal_connect(G_OBJECT(tasklist->move_minimized_radio), "toggled", (GCallback) move_minimized_toggled, tasklist);
+	g_signal_connect (tasklist->move_minimized_radio, "toggled",
+	                  (GCallback) move_minimized_toggled,
+	                  tasklist);
 
 	/* Tasklist content: */
 	tasklist_properties_update_content_radio (tasklist);
-	g_signal_connect(G_OBJECT(tasklist->show_all_radio), "toggled", (GCallback) display_all_workspaces_toggled, tasklist);
+	g_signal_connect (tasklist->show_all_radio, "toggled",
+	                  (GCallback) display_all_workspaces_toggled,
+	                  tasklist);
 
-	g_signal_connect_swapped(WID("done_button"), "clicked", (GCallback) gtk_widget_hide, tasklist->properties_dialog);
-	g_signal_connect(tasklist->properties_dialog, "response", G_CALLBACK(response_cb), tasklist);
+	g_signal_connect_swapped (WID ("done_button"), "clicked",
+	                          (GCallback) gtk_widget_hide,
+	                          tasklist->properties_dialog);
+	g_signal_connect (tasklist->properties_dialog, "response",
+	                  G_CALLBACK (response_cb),
+	                  tasklist);
 
 #ifdef HAVE_WAYLAND
 	if (GDK_IS_WAYLAND_DISPLAY(gdk_display_get_default())) {
