@@ -148,7 +148,8 @@ static const GtkActionEntry menu_entries[] = {
 static const GtkToggleActionEntry menu_toggle_entries[] = {
 	{ "Lock", NULL, N_("Loc_k To Panel"),
 	  NULL, NULL,
-	  G_CALLBACK (mate_panel_applet_menu_cmd_lock) }
+	  G_CALLBACK (mate_panel_applet_menu_cmd_lock),
+	  FALSE }
 };
 
 G_DEFINE_TYPE_WITH_PRIVATE (MatePanelApplet, mate_panel_applet, GTK_TYPE_EVENT_BOX)
@@ -844,36 +845,21 @@ mate_panel_applet_finalize (GObject *object)
 			g_dbus_connection_unregister_object (priv->connection,
 							     priv->object_id);
 		priv->object_id = 0;
-		g_object_unref (priv->connection);
-		priv->connection = NULL;
+		g_clear_object (&priv->connection);
 	}
 
-	if (priv->object_path) {
-		g_free (priv->object_path);
-		priv->object_path = NULL;
-	}
+	g_clear_pointer (&priv->object_path, g_free);
 
 	mate_panel_applet_set_preferences_path (applet, NULL);
 
-	if (priv->applet_action_group) {
-		g_object_unref (priv->applet_action_group);
-		priv->applet_action_group = NULL;
-	}
+	g_clear_object (&priv->applet_action_group);
+	g_clear_object (&priv->panel_action_group);
+	g_clear_object (&priv->ui_manager);
 
-	if (priv->panel_action_group) {
-		g_object_unref (priv->panel_action_group);
-		priv->panel_action_group = NULL;
-	}
-
-	if (priv->ui_manager) {
-		g_object_unref (priv->ui_manager);
-		priv->ui_manager = NULL;
-	}
-
-	g_free (priv->size_hints);
-	g_free (priv->prefs_path);
-	g_free (priv->background);
-	g_free (priv->id);
+	g_clear_pointer (&priv->size_hints, g_free);
+	g_clear_pointer (&priv->prefs_path, g_free);
+	g_clear_pointer (&priv->background, g_free);
+	g_clear_pointer (&priv->id, g_free);
 
 	/* closure is owned by the factory */
 	priv->closure = NULL;
@@ -1561,7 +1547,6 @@ mate_panel_applet_handle_background (MatePanelApplet *applet)
 
 			       0, PANEL_PIXMAP_BACKGROUND, NULL, pattern);
 
-
 		cairo_pattern_destroy (pattern);
 
 		break;
@@ -1625,9 +1610,8 @@ mate_panel_applet_change_background(MatePanelApplet *applet,
 	switch (type) {
 		case PANEL_NO_BACKGROUND:
 			if (priv->out_of_process){
-				cairo_pattern_t *transparent = cairo_pattern_create_rgba (0, 0, 0, 0);   /* Using NULL here breaks transparent */
-				gdk_window_set_background_pattern (window, transparent);                 /* backgrounds set by GTK theme */
-				cairo_pattern_destroy (transparent);
+				pattern = cairo_pattern_create_rgba (0,0,0,0);     /* Using NULL here breaks transparent */
+				gdk_window_set_background_pattern(window,pattern); /* backgrounds set by GTK theme */
 			}
 			break;
 		case PANEL_COLOR_BACKGROUND:
@@ -1806,7 +1790,7 @@ mate_panel_applet_setup (MatePanelApplet *applet)
 	MatePanelAppletPrivate *priv;
 	GValue   value = {0, };
 	GArray  *params;
-	gint     i;
+	guint     i;
 	gboolean ret;
 
 	priv = mate_panel_applet_get_instance_private (applet);
@@ -1958,7 +1942,7 @@ mate_panel_applet_constructor (GType                  type,
 		gtk_widget_set_name (widget, "PanelPlug");
 		_mate_panel_applet_prepare_css (context);
 
-		g_signal_connect_swapped (G_OBJECT (priv->plug), "embedded",
+		g_signal_connect_swapped (priv->plug, "embedded",
 		                          G_CALLBACK (mate_panel_applet_setup),
 		                          applet);
 
@@ -2009,7 +1993,6 @@ mate_panel_applet_class_init (MatePanelAppletClass *klass)
 	widget_class->realize = mate_panel_applet_realize;
 	widget_class->key_press_event = mate_panel_applet_key_press_event;
 
-
 	gobject_class->finalize = mate_panel_applet_finalize;
 
 	g_object_class_install_property (gobject_class,
@@ -2105,7 +2088,7 @@ mate_panel_applet_class_init (MatePanelAppletClass *klass)
 							       G_PARAM_READWRITE));
 
 	mate_panel_applet_signals [CHANGE_ORIENT] =
-                g_signal_new ("change_orient",
+                g_signal_new ("change-orient",
                               G_TYPE_FROM_CLASS (klass),
                               G_SIGNAL_RUN_LAST,
                               G_STRUCT_OFFSET (MatePanelAppletClass, change_orient),
@@ -2117,7 +2100,7 @@ mate_panel_applet_class_init (MatePanelAppletClass *klass)
 			      G_TYPE_UINT);
 
 	mate_panel_applet_signals [CHANGE_SIZE] =
-                g_signal_new ("change_size",
+                g_signal_new ("change-size",
                               G_TYPE_FROM_CLASS (klass),
                               G_SIGNAL_RUN_LAST,
                               G_STRUCT_OFFSET (MatePanelAppletClass, change_size),
@@ -2129,7 +2112,7 @@ mate_panel_applet_class_init (MatePanelAppletClass *klass)
 			      G_TYPE_INT);
 
 	mate_panel_applet_signals [CHANGE_BACKGROUND] =
-                g_signal_new ("change_background",
+                g_signal_new ("change-background",
                               G_TYPE_FROM_CLASS (klass),
                               G_SIGNAL_RUN_LAST,
                               G_STRUCT_OFFSET (MatePanelAppletClass, change_background),
@@ -2325,7 +2308,8 @@ static const gchar introspection_xml[] =
 static const GDBusInterfaceVTable interface_vtable = {
 	method_call_cb,
 	get_property_cb,
-	set_property_cb
+	set_property_cb,
+	{ 0 }
 };
 
 static GDBusNodeInfo *introspection_data = NULL;
@@ -2431,7 +2415,6 @@ _mate_panel_applet_factory_main_internal (const gchar               *factory_id,
 	g_return_val_if_fail(callback != NULL, 1);
 	g_assert(g_type_is_a(applet_type, PANEL_TYPE_APPLET));
 
-
 #ifdef HAVE_X11
 	if (GDK_IS_X11_DISPLAY (gdk_display_get_default ())) {
 		/*Use this both in and out of process as the tray applet always uses GtkSocket
