@@ -477,8 +477,7 @@ panel_action_button_finalize (GObject *object)
 		g_signal_handlers_disconnect_by_func (button->priv->settings,
 		                                      G_CALLBACK (panel_action_button_type_changed),
 		                                      button);
-		g_object_unref (button->priv->settings);
-		button->priv->settings = NULL;
+		g_clear_object (&button->priv->settings);
 	}
 
 	button->priv->info = NULL;
@@ -716,7 +715,6 @@ panel_action_button_load (PanelActionButtonType  type,
 
 	button = g_object_new (PANEL_TYPE_ACTION_BUTTON, "action-type", type, NULL);
 
-
 	button->priv->info = mate_panel_applet_register (GTK_WIDGET (button),
 						    NULL, NULL,
 						    panel, locked, position,
@@ -890,7 +888,7 @@ panel_action_button_set_dnd_enabled (PanelActionButton *button,
 	} else
 		gtk_drag_source_unset (GTK_WIDGET (button));
 
-	button->priv->dnd_enabled = enabled;
+	button->priv->dnd_enabled = (enabled != FALSE);
 
 	g_object_notify (G_OBJECT (button), "dnd-enabled");
 }
