@@ -102,7 +102,6 @@ void  mate_panel_applet_frame_change_background  (MatePanelAppletFrame    *frame
 void  mate_panel_applet_frame_set_panel          (MatePanelAppletFrame    *frame,
 					     PanelWidget         *panel);
 
-
 /* For module implementations only */
 
 typedef struct _MatePanelAppletFrameActivating        MatePanelAppletFrameActivating;
@@ -127,8 +126,8 @@ void  _mate_panel_applet_frame_update_flags          (MatePanelAppletFrame *fram
 						 gboolean          has_handle);
 
 void  _mate_panel_applet_frame_update_size_hints     (MatePanelAppletFrame *frame,
-						 gint             *size_hints,
-						 guint             n_elements);
+                                                      gint                 *size_hints,
+                                                      gsize                 n_elements);
 
 char *_mate_panel_applet_frame_get_background_string (MatePanelAppletFrame    *frame,
 						 PanelWidget         *panel,
