@@ -3,6 +3,7 @@
  *
  * Copyright (C) 2010 Carlos Garcia Campos <carlosgc@gnome.org>
  * Copyright (C) 2010 Vincent Untz <vuntz@gnome.org>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -39,7 +40,7 @@ MatePanelAppletInfo *mate_panel_applet_info_new (const gchar  *iid,
 						 gboolean      x11_supported,
 						 gboolean      wayland_supported);
 
-void             mate_panel_applet_info_free                            (MatePanelAppletInfo *info);
+void             mate_panel_applet_info_free                            (gpointer data);
 
 const gchar     *mate_panel_applet_info_get_iid                         (MatePanelAppletInfo *info);
 const gchar     *mate_panel_applet_info_get_name                        (MatePanelAppletInfo *info);
