@@ -2,6 +2,7 @@
  * panel-force-quit.h
  *
  * Copyright (C) 2003 Sun Microsystems, Inc.
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -25,7 +26,7 @@
 #ifndef __PANEL_FORCE_QUIT_H__
 #define __PANEL_FORCE_QUIT_H__
 
-#ifdef PACKAGE_NAME // only check HAVE_X11 if config.h has been included
+#ifdef PACKAGE_NAME /* only check HAVE_X11 if config.h has been included */
 #ifndef HAVE_X11
 #error file should only be included when HAVE_X11 is enabled
 #endif
