@@ -289,7 +289,7 @@ panel_widget_class_init (PanelWidgetClass *class)
 	GtkContainerClass *container_class = (GtkContainerClass*) class;
 
 	panel_widget_signals[SIZE_CHANGE_SIGNAL] =
-                g_signal_new ("size_change",
+                g_signal_new ("size-change",
                               G_TYPE_FROM_CLASS (object_class),
                               G_SIGNAL_RUN_LAST,
                               G_STRUCT_OFFSET (PanelWidgetClass, size_change),
@@ -300,7 +300,7 @@ panel_widget_class_init (PanelWidgetClass *class)
                               0);
 
 	panel_widget_signals[BACK_CHANGE_SIGNAL] =
-                g_signal_new ("back_change",
+                g_signal_new ("back-change",
                               G_TYPE_FROM_CLASS (object_class),
                               G_SIGNAL_RUN_LAST,
                               G_STRUCT_OFFSET (PanelWidgetClass, back_change),
@@ -311,7 +311,7 @@ panel_widget_class_init (PanelWidgetClass *class)
                               0);
 
 	panel_widget_signals[APPLET_MOVE_SIGNAL] =
-                g_signal_new ("applet_move",
+                g_signal_new ("applet-move",
                               G_TYPE_FROM_CLASS (object_class),
                               G_SIGNAL_RUN_LAST,
                               G_STRUCT_OFFSET (PanelWidgetClass, applet_move),
@@ -323,7 +323,7 @@ panel_widget_class_init (PanelWidgetClass *class)
                               G_TYPE_POINTER);
 
 	panel_widget_signals[APPLET_ADDED_SIGNAL] =
-                g_signal_new ("applet_added",
+                g_signal_new ("applet-added",
                               G_TYPE_FROM_CLASS (object_class),
                               G_SIGNAL_RUN_LAST,
                               G_STRUCT_OFFSET (PanelWidgetClass, applet_added),
@@ -335,7 +335,7 @@ panel_widget_class_init (PanelWidgetClass *class)
                               G_TYPE_POINTER);
 
 	panel_widget_signals[APPLET_REMOVED_SIGNAL] =
-                g_signal_new ("applet_removed",
+                g_signal_new ("applet-removed",
                               G_TYPE_FROM_CLASS (object_class),
                               G_SIGNAL_RUN_LAST,
                               G_STRUCT_OFFSET (PanelWidgetClass, applet_removed),
@@ -601,7 +601,6 @@ panel_widget_cremove (GtkContainer *container, GtkWidget *widget)
 	g_object_unref (widget);
 }
 
-
 /*get the list item of the data on the position pos*/
 static GList *
 get_applet_list_pos (PanelWidget *panel,
@@ -1153,7 +1152,6 @@ panel_widget_push_move (PanelWidget *panel,
 	}
 }
 
-
 /*this is a special function and may fail if called improperly, it works
 only under special circumstance when we know there is nothing from
 old_size to panel->size*/
@@ -1273,12 +1271,8 @@ panel_widget_get_preferred_size(GtkWidget	     *widget,
 	}
 
 	panel->nb_applets_size_hints = 0;
-	if (panel->applets_hints != NULL)
-		g_free (panel->applets_hints);
-	panel->applets_hints = NULL;
-	if (panel->applets_using_hint != NULL)
-		g_free (panel->applets_using_hint);
-	panel->applets_using_hint = NULL;
+	g_clear_pointer (&panel->applets_hints, g_free);
+	g_clear_pointer (&panel->applets_using_hint, g_free);
 
 	if (panel->packed) {
 		/* put the list in the correct order: this is important
@@ -1597,13 +1591,8 @@ panel_widget_finalize (GObject *obj)
 
 	panel = PANEL_WIDGET (obj);
 
-	if (panel->applets_hints != NULL)
-		g_free (panel->applets_hints);
-	panel->applets_hints = NULL;
-	if (panel->applets_using_hint != NULL)
-		g_free (panel->applets_using_hint);
-	panel->applets_using_hint = NULL;
-
+	g_clear_pointer (&panel->applets_hints, g_free);
+	g_clear_pointer (&panel->applets_using_hint, g_free);
 
 	G_OBJECT_CLASS (panel_widget_parent_class)->finalize (obj);
 }
@@ -1700,7 +1689,7 @@ panel_widget_new (PanelToplevel  *toplevel,
 	panel->orient = orient;
 	panel->sz = sz;
 
-	panel->packed = packed;
+	panel->packed = (packed != FALSE);
 	panel->size = 0;
 
 	panel->toplevel    = toplevel;
@@ -1762,7 +1751,6 @@ panel_widget_applet_drag_start_no_grab (PanelWidget *panel,
 	return TRUE;
 }
 
-
 static void
 panel_widget_applet_drag_end_no_grab (PanelWidget *panel)
 {
@@ -2311,7 +2299,6 @@ panel_sub_event_handler(GtkWidget *widget, GdkEvent *event, gpointer data)
 	return FALSE;
 }
 
-
 static void
 bind_applet_events(GtkWidget *widget, gpointer data)
 {
@@ -2326,9 +2313,9 @@ bind_applet_events(GtkWidget *widget, gpointer data)
 	 */
 
 	if (gtk_widget_get_has_window (widget))
-		g_signal_connect (G_OBJECT(widget), "event",
-				  G_CALLBACK (panel_sub_event_handler),
-				  data);
+		g_signal_connect (widget, "event",
+		                  G_CALLBACK (panel_sub_event_handler),
+		                  data);
 
 	if (GTK_IS_CONTAINER(widget))
 		gtk_container_foreach (GTK_CONTAINER (widget),
@@ -2367,7 +2354,7 @@ bind_top_applet_events (GtkWidget *widget)
 {
 	g_return_if_fail(GTK_IS_WIDGET(widget));
 
-	g_signal_connect (G_OBJECT(widget), "destroy",
+	g_signal_connect (widget, "destroy",
 			  G_CALLBACK (panel_widget_applet_destroy),
 			  NULL);
 
@@ -2506,7 +2493,7 @@ panel_widget_add (PanelWidget *panel,
 		ad->size_constrained = FALSE;
 		ad->expand_major = FALSE;
 		ad->expand_minor = FALSE;
-		ad->locked = locked;
+		ad->locked = (locked != FALSE);
 		ad->size_hints = NULL;
 		g_object_set_data (G_OBJECT (applet),
 				   MATE_PANEL_APPLET_DATA, ad);
@@ -2527,7 +2514,6 @@ panel_widget_add (PanelWidget *panel,
 		gtk_fixed_put(GTK_FIXED(panel),applet,
 			      0,pos);
 
-
 	gtk_widget_queue_resize(GTK_WIDGET(panel));
 
 	g_signal_emit (G_OBJECT(panel),
@@ -2613,7 +2599,7 @@ void
 panel_widget_set_packed (PanelWidget *panel_widget,
 			 gboolean     packed)
 {
-	panel_widget->packed = packed;
+	panel_widget->packed = (packed != FALSE);
 
 	gtk_widget_queue_resize (GTK_WIDGET (panel_widget));
 }
@@ -2811,7 +2797,6 @@ panel_widget_focus (PanelWidget *panel_widget)
 	gtk_widget_grab_focus (GTK_WIDGET (panel_widget));
 }
 
-
 PanelOrientation
 panel_widget_get_applet_orientation (PanelWidget *panel)
 {
@@ -2837,7 +2822,7 @@ panel_widget_set_applet_size_constrained (PanelWidget *panel,
 	if (ad->size_constrained == size_constrained)
 		return;
 
-	ad->size_constrained = size_constrained;
+	ad->size_constrained = (size_constrained != FALSE);
 
 	gtk_widget_queue_resize (GTK_WIDGET (panel));
 }
@@ -2860,8 +2845,8 @@ panel_widget_set_applet_expandable (PanelWidget *panel,
 	if (ad->expand_major == major && ad->expand_minor == minor)
 		return;
 
-	ad->expand_major = major;
-	ad->expand_minor = minor;
+	ad->expand_major = (major != FALSE);
+	ad->expand_minor = (minor != FALSE);
 
 	gtk_widget_queue_resize (GTK_WIDGET (panel));
 }
@@ -2902,7 +2887,7 @@ panel_widget_set_applet_locked (PanelWidget *panel,
 	if (!ad)
 		return;
 
-	ad->locked = locked;
+	ad->locked = (locked != FALSE);
 }
 
 gboolean
